### Description

Please provide a brief description of the changes in this PR. Include any relevant context or background information.

- **What**: Clearly and concisely describe what changes you have made.
- **Why**: Explain the reasoning behind these changes. What problem are you solving? Why is this change necessary?
- **How**: Describe how you implemented these changes. Provide an overview of the approach and any important implementation details.

### Changes Made

- **Added**: List new features or files added.
- **Modified**: Describe existing features or files modified.
- **Removed**: Detail features or files that were removed.

### Related Issues

Link to any related issues or discussions. Use keywords like "Fixes", "Resolves", or "Closes" to link to issues automatically.

- Fixes #
- Resolves #
- Closes #

### Breaking changes

Describe any breaking change.


### Additional Notes and Examples

Include any additional notes or context that reviewers should be aware of, including snippets of code illustrating your new feature.

---

**Please ensure your PR meets the following requirements:**

- [ ] Code builds and passes tests locally, including doctests
- [ ] New tests have been added (for bug fixes/features)
- [ ] Pre-commit passes
- [ ] PR to the documentation exists (for bug fixes / features)